Improve this doc View Source

Specify custom behavior when an element is swiped to the right on a touchscreen device. A rightward swipe is a quick, left-to-right slide of the finger. Though ngSwipeRight is designed for touch-based devices, it will work with a mouse click and drag too.

Requires the `ngTouch` module to be installed.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as attribute:

      <ANY
        ng-swipe-right="">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngSwipeRight | expression | Expression to evaluate upon right swipe. (Event object is available as `$event`)

## Example

Edit in Plunker

    <div ng-show="!showActions" ng-swipe-left="showActions = true">
      Some list content, like an email in the inbox
    </div>
    <div ng-show="showActions" ng-swipe-right="showActions = false">
      <button ng-click="reply()">Reply</button>
      <button ng-click="delete()">Delete</button>
    </div>

    angular.module('ngSwipeRightExample', ['ngTouch']);